@@ -166,7 +166,7 @@ plugin_topic_fmt = "%s/%s/%s"
 plugin_topics = {
     PluginTopic.P_BOOTSTRAP: MQTTTopic(PluginTopic.P_BOOTSTRAP),
     PluginTopic.P_DEV_CMD: MQTTTopic(PluginTopic.P_DEV_CMD),
-    PluginTopic.P_DEV_AUTH_CFG: MQTTTopic(PluginTopic.P_DEV_AUTH_CFG, True),
+    PluginTopic.P_DEV_AUTH_CFG: MQTTTopic(PluginTopic.P_DEV_AUTH_CFG, retain=True),
     PluginTopic.P_DEV_AUTH_KICK: MQTTTopic(PluginTopic.P_DEV_AUTH_KICK),
     PluginTopic.P_DEV_AUTH_CHECK: MQTTTopic(PluginTopic.P_DEV_AUTH_CHECK),
     PluginTopic.P_DEV_WIFI_CFG: MQTTTopic(PluginTopic.P_DEV_WIFI_CFG),
