@@ -166,7 +166,9 @@ class Blackwhite(Base):
     range = Column(Integer, nullable=False, info='范围 0 内网(MAC) 1 外网(IP或域名) ')
     text = Column(String(200, 'utf8mb4_0900_ai_ci'), nullable=False, server_default=FetchedValue())
     store_id = Column(Integer, nullable=False, index=True, server_default=FetchedValue(), info='场所id')
-
+    source = Column(Integer, index=True, server_default=FetchedValue(), info='0 手动 1 自动 21 接口（任子行） 22 接口（百卓）')
+    device_id = Column(Integer, index=True, server_default=FetchedValue(), info='绑定到设备的id号 0 没有绑定到设备')
+    label = Column(String(200), info='标签')
 
 
 class Branch(Base):
@@ -424,6 +426,7 @@ class SmsLog(Base):
     auth_code = Column(String(20, 'utf8mb4_0900_ai_ci'), nullable=False, info='短信验证码')
     date = Column(Date, nullable=False, info='日期')
     hour = Column(Integer, nullable=False, server_default=FetchedValue(), info='小时 0 - 23')
+    mac = Column(String(20, 'utf8mb4_0900_ai_ci'), nullable=True, server_default=FetchedValue(), info='mac地址')
 
 
 
@@ -522,19 +525,6 @@ class StoreExt(Base):
 
 
 
-class Whitelist(Base):
-    __tablename__ = 'whitelist'
-
-    id = Column(Integer, primary_key=True)
-    created_at = Column(DateTime, nullable=False, server_default=FetchedValue())
-    updated_at = Column(DateTime, nullable=False, server_default=FetchedValue())
-    mac = Column(String(17, 'utf8mb4_general_ci'), nullable=False, index=True, info='mac地址')
-    store_id = Column(Integer, nullable=False, index=True, server_default=FetchedValue(), info='场所ID号')
-    device_id = Column(Integer, nullable=False, index=True, info='设备ID号')
-    source = Column(Integer, nullable=False, index=True, info='0 手动 1 自动 21 任子行 22 百卓')
-
-
-
 class WhitelistPrefix(Base):
     __tablename__ = 'whitelist_prefix'
 
